@@ -12,6 +12,8 @@ from ptah import config
 from ptah.config import adapter
 from ptah.config import subscriber
 from ptah.config import get_cfg_storage
+from ptah.config import shutdown
+from ptah.config import shutdown_handler
 
 # uri
 from ptah.uri import resolve
